summaryrefslogtreecommitdiffstats
path: root/gst/asfmux/gstasfmux.c
diff options
context:
space:
mode:
Diffstat (limited to 'gst/asfmux/gstasfmux.c')
-rw-r--r--gst/asfmux/gstasfmux.c8
1 files changed, 7 insertions, 1 deletions
diff --git a/gst/asfmux/gstasfmux.c b/gst/asfmux/gstasfmux.c
index edc4bb71..83f52701 100644
--- a/gst/asfmux/gstasfmux.c
+++ b/gst/asfmux/gstasfmux.c
@@ -846,7 +846,13 @@ gst_asf_mux_write_extended_stream_properties (GstAsfMux * asfmux, guint8 ** buf,
GST_WRITE_UINT32_LE (*buf + 64, 0); /* maximum object size */
/* flags */
- GST_WRITE_UINT32_LE (*buf + 68, 0x0); /* TODO check if seekable */
+ if (asfpad->is_audio) {
+ /* TODO check if audio is seekable */
+ GST_WRITE_UINT32_LE (*buf + 68, 0x0);
+ } else {
+ /* video has indexes, so it is seekable */
+ GST_WRITE_UINT32_LE (*buf + 68, 0x2);
+ }
GST_WRITE_UINT16_LE (*buf + 72, asfpad->stream_number);
GST_WRITE_UINT16_LE (*buf + 74, 0); /* language index */